Package: robustrank
LazyLoad: yes
LazyData: yes
Version: 2024.1-28
Title: Robust Rank-Based Tests
Author: Youyi Fong <youyifong@gmail.com>
Maintainer: Youyi Fong <youyifong@gmail.com>
Depends: R (>= 3.2.0), kyotil
Suggests: RUnit, VGAM, copula, mvtnorm, pracma
Description: Implements two-sample tests for paired data with missing values (Fong, Huang, Lemos and McElrath 2018, Biostatics, <doi:10.1093/biostatistics/kxx039>) and modified Wilcoxon-Mann-Whitney two sample location test, also known as the Fligner-Policello test. 
License: GPL-2
NeedsCompilation: yes
Packaged: 2024-01-28 05:17:55 UTC; Youyi
Repository: CRAN
Date/Publication: 2024-01-28 05:30:02 UTC
Built: R 4.6.0; x86_64-apple-darwin20; 2026-04-27 02:10:42 UTC; unix
Archs: robustrank.so.dSYM
