useDynLib(robustrank, .registration = TRUE)

export(mod.wmw.test, pair.wmw.test, sim.partially.matched, r2sample, pm.wilcox.test, sim.paired.with.replicates, multinom.test, wmw.paired.replicates.test, mw.mw.2.perm, choose.test)

import(kyotil)

  importFrom("stats", "cov", "dexp", "dnorm", "ecdf", "pchisq", "pexp",
             "pnorm", "pt", "qexp", "qnorm", "rbeta", "rbinom", "rexp",
             "rgamma", "rlogis", "rmultinom", "rnorm", "runif",
             "uniroot", "var", "wilcox.test")
  importFrom("utils", "combn")
importFrom("stats", "cor", "sd")
